==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/GetDiskAccessPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property diskAccessName The name of the disk access resource that is being created. The name can't be changed after the disk encryption set is created. Supported characters for the name are a-z, A-Z, 0-9, _ and -. The maximum name length is 80 characters.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetDiskAccessPlainArgs(
    public val diskAccessName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs =
        com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs.builder()
            .diskAccessName(diskAccessName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDiskAccessPlainArgs].
 */
@PulumiTagMarker
public class GetDiskAccessPlainArgsBuilder internal constructor() {
    private var diskAccessName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the disk access resource that is being created. The name can't be changed after the disk encryption set is created. Supported characters for the name are a-z, A-Z, 0-9, _ and -. The maximum name length is 80 characters.
     */
    @JvmName("yygfsirmfwmswlpc")
    public suspend fun diskAccessName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.diskAccessName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("usmyvmxtnevbceum")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetDiskAccessPlainArgs = GetDiskAccessPlainArgs(
        diskAccessName = diskAccessName ?: throw PulumiNullFieldException("diskAccessName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/GetDiskAccessPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property diskAccessName The name of the disk access resource that is being created. The name can't be changed after the disk encryption set is created. Supported characters for the name are a-z, A-Z, 0-9, _ and -. The maximum name length is 80 characters.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetDiskAccessPlainArgs(
    public val diskAccessName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs =
        com.pulumi.azurenative.compute.inputs.GetDiskAccessPlainArgs.builder()
            .diskAccessName(diskAccessName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDiskAccessPlainArgs].
 */
@PulumiTagMarker
public class GetDiskAccessPlainArgsBuilder internal constructor() {
    private var diskAccessName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the disk access resource that is being created. The name can't be changed after the disk encryption set is created. Supported characters for the name are a-z, A-Z, 0-9, _ and -. The maximum name length is 80 characters.
     */
    @JvmName("engjigqyirpacnqs")
    public suspend fun diskAccessName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.diskAccessName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("oebynikrjjeobppq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetDiskAccessPlainArgs = GetDiskAccessPlainArgs(
        diskAccessName = diskAccessName ?: throw PulumiNullFieldException("diskAccessName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
